<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectBlockReferences</name>
    <message>
        <location filename="../SelectBlockReferencesInit.js" line="+2"/>
        <source>&amp;Select Block References</source>
        <translation>&amp;Zaznacz odniesienia bloku</translation>
    </message>
</context>
</TS>
